import { DsnComponents, Integration, Breadcrumb } from '@sentry/types';
import { ReplayPerformanceEntry } from './createPerformanceEntry';
import { IEventBuffer } from './eventBuffer';
import type { RRWebOptions, ReplaySpan, ReplayRequest, InstrumentationType, SentryReplayPluginOptions, SentryReplayConfiguration } from './types';
import { Session } from './session/Session';
/**
 * Returns true if we want to flush immediately, otherwise continue with normal batching
 */
declare type AddUpdateCallback = () => boolean | void;
export declare class SentryReplay implements Integration {
    /**
     * @inheritDoc
     */
    static id: string;
    /**
     * @inheritDoc
     */
    name: string;
    eventBuffer: IEventBuffer;
    /**
     * Buffer of breadcrumbs to be uploaded
     */
    breadcrumbs: Breadcrumb[];
    /**
     * Buffer of replay spans to be uploaded
     */
    replaySpans: ReplaySpan[];
    /**
     * List of PerformanceEntry from PerformanceObserver
     */
    performanceEvents: PerformanceEntry[];
    /**
     * Options to pass to `rrweb.record()`
     */
    readonly rrwebRecordOptions: RRWebOptions;
    readonly options: SentryReplayPluginOptions;
    /**
     * setTimeout id used for debouncing sending rrweb attachments
     */
    private timeout;
    /**
     * The timestamp of the first event since the last flush.
     * This is used to determine if the maximum allowed time has passed before we should flush events again.
     */
    private initialEventTimestampSinceFlush;
    private performanceObserver;
    private retryCount;
    private retryInterval;
    /**
     * Flag to make sure we only create a replay event when
     * necessary (i.e. we only want to have a single replay
     * event per session and it should only be created
     * immediately before sending recording)
     */
    private needsCaptureReplay;
    session: Session | undefined;
    static attachmentUrlFromDsn(dsn: DsnComponents, eventId: string): string;
    constructor({ uploadMinDelay, uploadMaxDelay, stickySession, // TBD: Making this opt-in for now
    useCompression, rrwebConfig: { maskAllInputs, blockClass, ignoreClass, maskTextClass, ...rrwebRecordOptions }, }?: SentryReplayConfiguration);
    setupOnce(): void;
    setup(): void;
    /**
     * We want to batch uploads of replay events. Save events only if
     * `<uploadMinDelay>` milliseconds have elapsed since the last event
     * *OR* if `<uploadMaxDelay>` milliseconds have elapsed.
     *
     * Accepts a callback to perform side-effects and returns a boolean value if we
     * should flush events immediately
     */
    addUpdate(cb?: AddUpdateCallback): void;
    /**
     * Currently, this needs to be manually called (e.g. for tests). Sentry SDK does not support a teardown
     */
    destroy(): void;
    clearSession(): void;
    /**
     * Loads a session from storage, or creates a new one if it does not exist or
     * is expired.
     */
    loadSession({ expiry }: {
        expiry: number;
    }): void;
    addListeners(): void;
    removeListeners(): void;
    /**
     * Handle when visibility of the page content changes. Opening a new tab will
     * cause the state to change to hidden because of content of current page will
     * be hidden. Likewise, moving a different window to cover the contents of the
     * page will also trigger a change to a hidden state.
     */
    handleVisibilityChange: () => void;
    /**
     * Handle when page is blurred
     */
    handleWindowBlur: () => void;
    /**
     * Handle when page is focused
     */
    handleWindowFocus: () => void;
    handleWindowUnload: () => void;
    handleCoreListener: (type: InstrumentationType) => (handlerData: any) => void;
    /**
     * Keep a list of performance entries that will be sent with a replay
     */
    handlePerformanceObserver: (list: PerformanceObserverEntryList) => void;
    /**
     * Tasks to run when we consider a page to be hidden (via blurring and/or visibility)
     */
    doChangeToBackgroundTasks(breadcrumb?: Breadcrumb): void;
    /**
     * Tasks to run when we consider a page to be visible (via focus and/or visibility)
     */
    doChangeToForegroundTasks(breadcrumb?: Breadcrumb): void;
    /**
     * Trigger rrweb to take a full snapshot which will cause this plugin to
     * create a new Replay event.
     */
    triggerFullSnapshot(): void;
    updateLastActivity(lastActivity?: number): void;
    createCustomBreadcrumb(breadcrumb: Breadcrumb): void;
    /**
     * Create a span for each performance entry. The parent transaction is `this.replayEvent`.
     */
    createPerformanceSpans(entries: ReplayPerformanceEntry[]): void;
    /**
     * Observed performance events are added to `this.performanceEvents`. These
     * are included in the replay event before it is finished and sent to Sentry.
     */
    addPerformanceEntries(): void;
    /**
     *
     *
     * Returns true if session is not expired, false otherwise.
     */
    checkAndHandleExpiredSession(expiry?: number): boolean;
    flushUpdate(lastActivity?: number): Promise<void>;
    /**
     * Determine if there is browser support for `navigator.sendBeacon`
     */
    hasSendBeacon(): boolean;
    /**
     * Send replay attachment using either `sendBeacon()` or `fetch()`
     */
    sendReplayRequest({ endpoint, events }: ReplayRequest): Promise<void>;
    resetRetries(): void;
    /**
     * Finalize and send the current replay event to Sentry
     */
    sendReplay(eventId: string, events: Uint8Array | string): Promise<boolean>;
}
export {};
